@@ -18,7 +18,7 @@ require Exporter;
  crc64_hex crc64_base64
 );
 
-$VERSION    = '0.19';
+$VERSION    = '0.20';
 $XS_VERSION = $VERSION;
 #$VERSION    = eval $VERSION;
 
@@ -248,7 +248,6 @@ sub b64digest {
 
 sub clone {
   my $self = shift;
-  use Data::Dumper; print Dumper $self;
   my $clone = { 
     type => $self->{type},
     width => $self->{width},
@@ -261,7 +260,6 @@ sub clone {
     cont => $self->{cont},
     _tab => $self->{_tab}
   };
-  use Data::Dumper; print Dumper $clone;
   bless $clone, ref $self || $self;
 }
 
